# Table of Contents

- [ai-governance-and-adoption-evaluate-risks](<./ai-governance-and-adoption-evaluate-risks.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Step 3: Evaluate AI-Related Risks](<./Step-3-Evaluate-AI-Related-Risks.md>)
  - [AI Risk Associated with Applications](<./Step-3-Evaluate-AI-Related-Risks/AI-Risk-Associated-with-Applications.md>)
  - [AI Risk Associated with AI Agents](<./Step-3-Evaluate-AI-Related-Risks/AI-Risk-Associated-with-AI-Agents.md>)
  - [Best Practices](<./Step-3-Evaluate-AI-Related-Risks/Best-Practices.md>)
  - [Was this page helpful?](<./Step-3-Evaluate-AI-Related-Risks/Was-this-page-helpful.md>)
